lightspeed

Public root module for Lightspeed.

Values

pub fn banner() -> String

Returns a short runtime banner useful for logs and examples.

pub const package_version: String

The current Lightspeed package version exposed to application code.

pub const protocol_name: String

The current Lightspeed protocol name.

pub const protocol_version: Int

The current Lightspeed protocol version.

Search Document