lightspeed
Public root module for Lightspeed.
Values
pub const package_version: String
The current Lightspeed package version exposed to application code.
Public root module for Lightspeed.
pub const package_version: String
The current Lightspeed package version exposed to application code.